==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/ibanbicdata/ibanbicdata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[de]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[et]": "Christian Dávid",
                "Name[eu]": "Christian Dávid",
                "Name[fi]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[ia]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[ko]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sl]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[x-test]": "xxChristian Dávidxx",
                "Name[zh_CN]": "Christian Dávid"
            }
        ],
        "Description": "Adds predefined IBAN/BIC numbers to KMyMoney",
        "Description[ca@valencia]": "Afig números IBAN/BIC predefinits al KMyMoney",
        "Description[ca]": "Afegeix números IBAN/BIC predefinits al KMyMoney",
        "Description[de]": "Fügt vordefinierte IBAN- und BIC-Nummern zu KMyMoney hinzu",
        "Description[en_GB]": "Adds predefined IBAN/BIC numbers to KMyMoney",
        "Description[es]": "Añade números IBAN/BIC predefinidos a KMyMoney",
        "Description[et]": "IBAN/BIC etteantud numbrite lisamine KMyMoneys",
        "Description[eu]": "Aurrez definitutako IBAN/BIC zenbakiak gehitzen ditu KMyMoneyra",
        "Description[fi]": "Lisää KMyMoneyyn ennalta asetetut IBAN/BIC-numerot",
        "Description[fr]": "Ajoute des numéros IBAN/BIC prédéfinis à KMyMoney",
        "Description[gl]": "Engade números predefinidos de IBAN e BIC a KMyMoney",
        "Description[it]": "Aggiunge i numeri IBAN/BIC predefiniti a KMyMoney",
        "Description[ko]": "KMyMoney에 미리 정의된 IBAN/BIC 번호 추가",
        "Description[nl]": "Voegt voorgedefinieerde IBAN/BIC-nummers toe aan KMyMoney",
        "Description[pl]": "Dodaje uprzednio określone numery IBAN/BIC do KMyMoney",
        "Description[pt]": "Adiciona os números IBAN/BIC predefinidos ao KMyMoney",
        "Description[pt_BR]": "Adiciona números IBAN/BIC pré-definidos no KMyMoney",
        "Description[sk]": "Pridá preddefinované IBAN/BIC čísla do KMyMoney",
        "Description[sl]": "V KMyMoney doda vnaprej določene številke IBAN/BIC",
        "Description[sv]": "Lägger till fördefinierade IBAN/BIC-nummer i KMyMoney",
        "Description[uk]": "Попередньо визначені номери IBAN/BIC у KMyMoney",
        "Description[x-test]": "xxAdds predefined IBAN/BIC numbers to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加预定义的国际银行账号/银行识别码",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "ibanbicdata",
        "License": "GPL",
        "Name": "IBAN/BIC Data",
        "Name[ca@valencia]": "Dades IBAN i BIC",
        "Name[ca]": "Dades IBAN i BIC",
        "Name[de]": "IBAN/BIC-Daten",
        "Name[en_GB]": "IBAN/BIC Data",
        "Name[es]": "Datos IBAN/BIC",
        "Name[et]": "IBAN/BIC andmed",
        "Name[eu]": "IBAN/BIC datuak",
        "Name[fi]": "IBAN / BIC",
        "Name[fr]": "Données IBAN/BIC",
        "Name[gl]": "Datos de IBAN e BIC",
        "Name[ia]": "Datos de IBAN/BIC",
        "Name[it]": "Dati IBAN/BIC",
        "Name[ko]": "IBAN/BIC 데이터",
        "Name[nl]": "IBAN/BIC gegevens",
        "Name[pl]": "Dane IBAN/BIC",
        "Name[pt]": "Dados do IBAN/BIC",
        "Name[pt_BR]": "Dados IBAN/BIC",
        "Name[sk]": "IBAN/BIC Údaje",
        "Name[sl]": "Podatki IBAN/BIC",
        "Name[sv]": "IBAN- och BIC-data",
        "Name[uk]": "Дані IBAN та BIC",
        "Name[x-test]": "xxIBAN/BIC Dataxx",
        "Name[zh_CN]": "国际银行账号/银行识别码数据",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.1.90.tar.xz: kmymoney-5.1.90/kmymoney/plugins/ibanbicdata/ibanbicdata.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "christian-david@web.de",
                "Name": "Christian Dávid",
                "Name[ca@valencia]": "Christian Dávid",
                "Name[ca]": "Christian Dávid",
                "Name[cs]": "Christian Dávid",
                "Name[de]": "Christian Dávid",
                "Name[en_GB]": "Christian Dávid",
                "Name[eo]": "Christian Dávid",
                "Name[es]": "Christian Dávid",
                "Name[et]": "Christian Dávid",
                "Name[eu]": "Christian Dávid",
                "Name[fi]": "Christian Dávid",
                "Name[fr]": "Christian Dávid",
                "Name[gl]": "Christian Dávid",
                "Name[ia]": "Christian Dávid",
                "Name[it]": "Christian Dávid",
                "Name[ka]": "Christian Dávid",
                "Name[ko]": "Christian Dávid",
                "Name[nb]": "Christian Dávid",
                "Name[nl]": "Christian Dávid",
                "Name[pl]": "Christian Dávid",
                "Name[pt]": "Christian Dávid",
                "Name[pt_BR]": "Christian Dávid",
                "Name[ru]": "Christian Dávid",
                "Name[sk]": "Christian Dávid",
                "Name[sl]": "Christian Dávid",
                "Name[sv]": "Christian Dávid",
                "Name[tr]": "Christian Dávid",
                "Name[uk]": "Christian Dávid",
                "Name[x-test]": "xxChristian Dávidxx",
                "Name[zh_CN]": "Christian Dávid",
                "Name[zh_TW]": "Christian Dávid"
            }
        ],
        "Description": "Adds predefined IBAN/BIC numbers to KMyMoney",
        "Description[ca@valencia]": "Afig números IBAN/BIC predefinits a KMyMoney",
        "Description[ca]": "Afegeix números IBAN/BIC predefinits al KMyMoney",
        "Description[de]": "Fügt vordefinierte IBAN- und BIC-Nummern zu KMyMoney hinzu",
        "Description[en_GB]": "Adds predefined IBAN/BIC numbers to KMyMoney",
        "Description[eo]": "Aldonas antaŭdifinitajn IBAN/BIC-numerojn al KMyMoney",
        "Description[es]": "Añade números IBAN/BIC predefinidos a KMyMoney",
        "Description[et]": "IBAN/BIC etteantud numbrite lisamine KMyMoneys",
        "Description[eu]": "Aurrez definitutako IBAN/BIC zenbakiak gehitzen ditu KMyMoneyra",
        "Description[fi]": "Lisää KMyMoneyyn ennalta asetetut IBAN/BIC-numerot",
        "Description[fr]": "Ajoute des numéros IBAN/BIC prédéfinis à KMyMoney",
        "Description[gl]": "Engade números predefinidos de IBAN e BIC a KMyMoney",
        "Description[it]": "Aggiunge i numeri IBAN/BIC predefiniti a KMyMoney",
        "Description[ka]": "KMyMoney-ში წინასწარ განსაზღვრული IBAN/BIC რიცხვების დამატება",
        "Description[ko]": "KMyMoney에 미리 정의된 IBAN/BIC 번호 추가",
        "Description[nb]": "Legger til forhåndsdefinerte IBAN/BIC-nummer i KMyMoney",
        "Description[nl]": "Voegt voorgedefinieerde IBAN/BIC-nummers toe aan KMyMoney",
        "Description[pl]": "Dodaje uprzednio określone numery IBAN/BIC do KMyMoney",
        "Description[pt]": "Adiciona os números IBAN/BIC predefinidos ao KMyMoney",
        "Description[pt_BR]": "Adiciona números IBAN/BIC pré-definidos no KMyMoney",
        "Description[ru]": "Добавляет в KMyMoney базу данных номеров IBAN/BIC",
        "Description[sk]": "Pridá preddefinované IBAN/BIC čísla do KMyMoney",
        "Description[sl]": "V KMyMoney doda vnaprej določene številke IBAN/BIC",
        "Description[sv]": "Lägger till fördefinierade IBAN/BIC-nummer i KMyMoney",
        "Description[tr]": "K Param'a önceden tanımlanmış IBAN/BIC numaralarını ekler",
        "Description[uk]": "Попередньо визначені номери IBAN/BIC у KMyMoney",
        "Description[x-test]": "xxAdds predefined IBAN/BIC numbers to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加预定义的国际银行账号/银行识别码",
        "Description[zh_TW]": "提供預先定義的 IBAN/BIC 號碼給 KMyMoney",
        "EnabledByDefault": true,
        "Icon": "server-database",
        "Id": "ibanbicdata",
        "License": "GPL",
        "Name": "IBAN/BIC Data",
        "Name[ca@valencia]": "Dades IBAN i BIC",
        "Name[ca]": "Dades IBAN i BIC",
        "Name[de]": "IBAN/BIC-Daten",
        "Name[en_GB]": "IBAN/BIC Data",
        "Name[eo]": "Datumoj de IBAN/BIC",
        "Name[es]": "Datos IBAN/BIC",
        "Name[et]": "IBAN/BIC andmed",
        "Name[eu]": "IBAN/BIC datuak",
        "Name[fi]": "IBAN / BIC",
        "Name[fr]": "Données IBAN/BIC",
        "Name[gl]": "Datos de IBAN e BIC",
        "Name[ia]": "Datos de IBAN/BIC",
        "Name[it]": "Dati IBAN/BIC",
        "Name[ka]": "IBAN/BIC მონაცემები",
        "Name[ko]": "IBAN/BIC 데이터",
        "Name[nb]": "IBAN/BIC-data",
        "Name[nl]": "IBAN/BIC gegevens",
        "Name[pl]": "Dane IBAN/BIC",
        "Name[pt]": "Dados do IBAN/BIC",
        "Name[pt_BR]": "Dados IBAN/BIC",
        "Name[ru]": "Данные IBAN/BIC",
        "Name[sk]": "IBAN/BIC Údaje",
        "Name[sl]": "Podatki IBAN/BIC",
        "Name[sv]": "IBAN- och BIC-data",
        "Name[tr]": "IBAN/BIC Verisi",
        "Name[uk]": "Дані IBAN та BIC",
        "Name[x-test]": "xxIBAN/BIC Dataxx",
        "Name[zh_CN]": "国际银行账号/银行识别码数据",
        "Name[zh_TW]": "IBAN/BIC Data",
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
